## Add support for release candidate number
<!--
type: feature
scope: all
affected: all
-->

cmk-dev-install (or cmk-dev-site-install) now support `2.M.0{pP|bB}-rcN` as version input.
`N` stands for the release candidate number.
